@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-package Git::Fingerd 2.093522;
+package Git::Fingerd 2.093523;
 use Net::Finger::Server 0.003;
 BEGIN { our @ISA = qw(Net::Finger::Server); }
 # ABSTRACT: let people finger your git server for... some reason
@@ -147,7 +147,7 @@ Git::Fingerd - let people finger your git server for... some reason
 
 =head1 VERSION
 
-version 2.093522
+version 2.093523
 
 =head1 DESCRIPTION
 
@@ -182,7 +182,7 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 CONTRIBUTOR
 
